@@ -1,14 +1,14 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from trytond.model import fields
 from trytond.pool import Pool, PoolMeta
+from trytond.transaction import Transaction
 
 
 __all__ = ['StockMove']
-__metaclass__ = PoolMeta
 
 
-class StockMove:
+class StockMove(metaclass=PoolMeta):
     __name__ = 'stock.move'
     invoice_lines = fields.Many2Many('account.invoice.line-stock.move',
         'stock_move', 'invoice_line', 'Invoice Lines')
@@ -30,5 +30,6 @@ class StockMove:
             default = {}
         else:
             default = default.copy()
-        default.setdefault('invoice_lines', None)
+        if not Transaction().context.get('_stock_move_split'):
+            default.setdefault('invoice_lines', None)
         return super(StockMove, cls).copy(moves, default=default)
